@@ -50,6 +50,9 @@ class GDBCtrl:
         self._mi = Output(nl='\n')
         self._gdb = None
 
+    def is_alive(self):
+        return self._gdb is not None
+
     async def spawn(
         self,
         path2bin=None,
